#C The above RLE pattern is a Unit Life Cell.  This is an object which plays
#C the Game of Life on a larger scale.  This one is 500 cells on a side,
#C and represents one Cell for the larger scale.  You just construct a Life
#C object to be Run by making a rectangular array of these Unit Life Cells,
#C then changing the state of the Cells to be LIVE or DEAD to represent an
#C Object to be run, and then running the whole object.  Each Unit Life Cell
#C calculates its new state based on its current state and that of its eight
#C neighboring Cells using the Life rule.  So the object calculates the fate
#C of the initial Object which you have put into it.  This is rather slow,
#C however, since the object is rather large, and each larger scale Generation
#C takes 5760 generations to compute.
#C 
#C In the above RLE pattern, the state of the Unit Life Cell is encoded by
#C the presence or absence of a particular glider in the Cell.  This glider
#C is contained within the upper left region of the Cell between two long boats.
#C Keeping the glider means that the Cell is LIVE, and deleting the glider
#C means that the Cell is DEAD.  This is the only difference between the two
#C states at this particular generation in the cycle.  At other generations
#C in the period 5760 cycle, there are more differences between the two states.
#C You can see the state of the Object at any multiple of 5760 generations
#C by seeing which Cells have the presence of the glider between the boats.
#C 
#C Multiple Unit Life Cells are aligned using the long boats at the corners
#C of the Cells.  You should place a one cell gap between neighboring Cells,
#C as in the following picture which is the meeting place between four Cells.
#C This makes the offset between neighboring Cells exactly 500 cells.
#C You should always make a rectangle of Unit Life Cells, since otherwise
#C stray gliders will destroy them.
#C 
#C  .O.....O.
#C  O.O...O.O
#C  .O.O.O.O.
#C  ..OO.OO..
#C  .........
#C  ..OO.OO..
#C  .O.O.O.O.
#C  O.O...O.O
#C  .O.....O.
#C 
#C 
#C The Unit Life Cell communicates its state to its neighbor Cells by emitting
#C eight gliders to those Cells if the current state of the Cell is LIVE.
#C It detects neighboring Cell states by capturing the incoming eight gliders,
#C if they are present.  Then the Unit Life Cell counts the gliders and
#C applies the Life rule to change its state.
#C 
#C 
#C Here is a detailed description of the construction of the Unit Life Cell:
#C 
#C In the upper center is a fanout device made up of many glider guns and a
#C LWSS gun.  This construction was originally designed by Bill Gosper.
#C The LWSS stream normally destroys all of the gliders emitted by the guns.
#C But when a LWSS is deleted by an incoming glider, then one glider escapes
#C through the hole from each of the glider guns.  There are eight glider guns
#C so as to replicate the current state for each of the neighboring Cells.
#C In addition, the LWSS itself is used to save the current state of this Cell
#C for use in calculating the Life rule.
#C 
#C In the left center is a "chute" made up of a number of queen bee pairs.
#C These are detectors for incoming gliders.  A reaction between a queen
#C bee pair and an incoming glider results in a block which is out of the
#C way of the queen bees, and within the chute.  In this way the incoming
#C gliders (if present) can arrive at various times, and their state is kept
#C steady until all of them are accumulated.
#C 
#C At the bottom of the chute is a triggerable glider gun which when triggered
#C sends 10 gliders up the chute from the lower right to the upper left.
#C (Only 8 are necessary but I didn't find such a reaction and 10 is harmless.)
#C These gliders are used to sweep up the blocks which may have been left
#C in the chute by the incoming gliders.  Each reaction destroys one block
#C and one glider.  So when the gliders arrive at the top of the chute,
#C the time at which the first glider arrives indicates the number of blocks
#C that were swept away, and thus the number of LIVE neighboring Cells.
#C 
#C At the top of the chute is a glider stream which when interrupted only
#C allows three of the gliders in the chute through (if present).  Number
#C the chute gliders g0, g1, g2, g3, g4, g5, g6, g7, g8, and g9,
#C representing the number of blocks that were present.  A glider hitting
#C the stream at the right time deletes three of the gliders in the stream
#C so as to only allow gliders g1, g2, and g3 through (if present).
#C 
#C At the middle of the left edge is the logic circuit which calculates the
#C Life rule based on the presence of the gliders g1, g2, and g3, and the
#C presence or absence of another incoming glider which represents this
#C Cell's current state.  The logic for calculating the Life rule was
#C designed by Dean Hickerson, and implemented by me.  If the new state of
#C the cell is LIVE, then a glider is emitted by the circuit.
#C 
#C At the upper right at the end of the LWSS stream is a bit holder, which
#C turns the absence of an LWSS into a boat.  This boat holds the current
#C state of this Cell until it is required.  At the appropriate time, an
#C incoming glider hits the boat (if present) to start a glider on its
#C journey across the top of the Cell to the Life rule logic.
#C 
#C At the lower left, lower right, and upper right are three high period
#C glider guns.  These are the "clocks" which run the Unit Life Cell's cycle
#C and determine the length of a Generation.  The one at the lower right
#C triggers the stream of 10 gliders to count the number of blocks in the
#C chute.  The one at the lower left triggers the opening of the glider
#C stream to let the g1, g2, and g3 gliders through.  It also occasionally
#C spits out an extra glider which does no harm.  The one at the upper right
#C is used to start the glider representing the current state of the Cell on
#C its journey.
#C 
#C The rest of the logic consists of glider turning reactions, and delay
#C reactions in order to route the gliders from the fanout device to the
#C neighboring cell's chute detectors.  These were rather tricky to set up
#C so that nothing ran into anything else!  Some of the glider turners use a
#C pair of glider guns because the small glider turner has the wrong parity
#C for the output glider.
#C 
#C 
#C Here are some approximate generation numbers for important events which
#C occur during the 5760 generations which make up one Generation.  Some of
#C these events only occur if the Cell or its neigbors are LIVE.
#C 
#C 0:	Current state glider starts from pair of long boats
#C 400:	Current state glider arrives at fanout device
#C 600:	Output gliders escape from the fanout device
#C 900:	Missing LWSS turned into boat to hold Cell's current state
#C 1800:	First glider arrives at the chute to be turned into a block
#C 4000:	Last glider arrives at the chute to be turned into a block
#C 	and the high period glider guns fire
#C 4700:	Stream of 10 gliders starts sweep through the chute to count
#C 	the number of blocks in the chute
#C 5200:	Gliders from stream react in the Life Logic circuit to calculate
#C 	the new current state glider
#C 5760:	New current state glider arrives back at the pair of long boats
#C 
#C David I. Bell, January 1996
#C "main" (cells 4761 width 499 height 499 generation 0)
#R
-249 -249
-248 -249
248 -249
249 -249
-249 -248
-247 -248
247 -248
249 -248
-248 -247
-246 -247
246 -247
248 -247
-247 -246
247 -246
-58 -238
-57 -238
-58 -237
-71 -236
-60 -236
-58 -236
46 -236
47 -236
-72 -235
-70 -235
-60 -235
-59 -235
46 -235
-113 -234
-74 -234
-73 -234
-69 -234
38 -234
44 -234
46 -234
-115 -233
-114 -233
-113 -233
-79 -233
-78 -233
-74 -233
-73 -233
-69 -233
37 -233
38 -233
39 -233
40 -233
44 -233
45 -233
-116 -232
-79 -232
-78 -232
-74 -232
-73 -232
-69 -232
36 -232
37 -232
39 -232
41 -232
-116 -231
-115 -231
-72 -231
-70 -231
25 -231
26 -231
35 -231
36 -231
37 -231
39 -231
42 -231
-71 -230
25 -230
26 -230
36 -230
37 -230
39 -230
41 -230
37 -229
38 -229
39 -229
40 -229
-118 -228
38 -228
-119 -227
-117 -227
-120 -226
-116 -226
-119 -225
-118 -225
-117 -225
134 -225
135 -225
-121 -224
-120 -224
-116 -224
-115 -224
134 -224
135 -224
133 -215
134 -215
135 -215
132 -214
136 -214
-118 -213
-117 -213
131 -213
137 -213
221 -213
222 -213
-118 -212
-117 -212
131 -212
137 -212
221 -212
222 -212
134 -211
132 -210
136 -210
117 -209
118 -209
133 -209
134 -209
135 -209
117 -208
118 -208
134 -208
131 -206
132 -206
132 -205
129 -204
130 -204
131 -204
117 -203
118 -203
119 -203
129 -203
117 -202
118 -202
119 -202
116 -201
120 -201
220 -201
221 -201
222 -201
223 -201
224 -201
153 -200
155 -200
219 -200
221 -200
222 -200
223 -200
225 -200
115 -199
116 -199
120 -199
121 -199
145 -199
146 -199
147 -199
153 -199
157 -199
220 -199
224 -199
140 -198
141 -198
144 -198
147 -198
149 -198
157 -198
221 -198
222 -198
223 -198
138 -197
141 -197
144 -197
145 -197
153 -197
158 -197
163 -197
164 -197
222 -197
137 -196
146 -196
157 -196
163 -196
164 -196
137 -195
149 -195
150 -195
153 -195
157 -195
137 -194
147 -194
153 -194
155 -194
131 -193
132 -193
138 -193
141 -193
147 -193
148 -193
224 -193
130 -192
132 -192
140 -192
141 -192
145 -192
147 -192
224 -192
130 -191
145 -191
146 -191
147 -191
217 -191
223 -191
225 -191
120 -190
121 -190
129 -190
130 -190
217 -190
219 -190
222 -190
223 -190
225 -190
226 -190
120 -189
217 -189
218 -189
221 -189
227 -189
121 -188
122 -188
123 -188
224 -188
123 -187
221 -187
222 -187
226 -187
227 -187
164 -186
165 -186
187 -186
188 -186
152 -185
153 -185
154 -185
157 -185
163 -185
167 -185
187 -185
188 -185
148 -184
152 -184
162 -184
168 -184
172 -184
173 -184
146 -183
148 -183
153 -183
162 -183
166 -183
168 -183
169 -183
172 -183
173 -183
144 -182
145 -182
162 -182
168 -182
-219 -181
144 -181
145 -181
163 -181
167 -181
-219 -180
-218 -180
-217 -180
-16 -180
144 -180
145 -180
164 -180
165 -180
-216 -179
-18 -179
-16 -179
22 -179
53 -179
140 -179
141 -179
146 -179
148 -179
-217 -178
-216 -178
-26 -178
-25 -178
-20 -178
-19 -178
22 -178
23 -178
24 -178
53 -178
54 -178
55 -178
139 -178
141 -178
148 -178
-26 -177
-25 -177
-20 -177
-19 -177
25 -177
56 -177
139 -177
218 -177
227 -177
-20 -176
-19 -176
13 -176
14 -176
24 -176
25 -176
55 -176
56 -176
138 -176
139 -176
185 -176
186 -176
188 -176
190 -176
191 -176
217 -176
218 -176
226 -176
227 -176
228 -176
-215 -175
-214 -175
-213 -175
-18 -175
-16 -175
-7 -175
-6 -175
13 -175
14 -175
215 -175
219 -175
225 -175
226 -175
227 -175
228 -175
229 -175
-215 -174
-214 -174
-213 -174
-16 -174
-7 -174
-5 -174
185 -174
191 -174
214 -174
216 -174
217 -174
224 -174
226 -174
228 -174
230 -174
-216 -173
-212 -173
-5 -173
57 -173
58 -173
59 -173
207 -173
208 -173
214 -173
216 -173
224 -173
225 -173
229 -173
230 -173
-217 -172
-211 -172
-23 -172
-5 -172
-4 -172
57 -172
58 -172
59 -172
186 -172
187 -172
189 -172
190 -172
206 -172
208 -172
-216 -171
-212 -171
-24 -171
-22 -171
56 -171
60 -171
188 -171
206 -171
-215 -170
-214 -170
-213 -170
-34 -170
-33 -170
-26 -170
-25 -170
-21 -170
24 -170
25 -170
27 -170
29 -170
30 -170
205 -170
206 -170
215 -170
216 -170
224 -170
225 -170
-35 -169
-33 -169
-28 -169
-27 -169
-25 -169
-21 -169
24 -169
30 -169
55 -169
56 -169
60 -169
61 -169
195 -169
215 -169
216 -169
224 -169
225 -169
-36 -168
-35 -168
-34 -168
-29 -168
-28 -168
-27 -168
-25 -168
-21 -168
25 -168
29 -168
180 -168
181 -168
194 -168
223 -168
-45 -167
-44 -167
-37 -167
-36 -167
-35 -167
-30 -167
-27 -167
-26 -167
-24 -167
-22 -167
-13 -167
-12 -167
26 -167
27 -167
28 -167
173 -167
174 -167
175 -167
180 -167
181 -167
194 -167
195 -167
196 -167
203 -167
204 -167
223 -167
224 -167
225 -167
-45 -166
-44 -166
-36 -166
-35 -166
-34 -166
-29 -166
-28 -166
-23 -166
-13 -166
-11 -166
172 -166
173 -166
174 -166
175 -166
176 -166
183 -166
184 -166
203 -166
204 -166
227 -166
-35 -165
-33 -165
-11 -165
10 -165
11 -165
15 -165
16 -165
171 -165
173 -165
177 -165
183 -165
184 -165
185 -165
223 -165
224 -165
225 -165
226 -165
227 -165
-34 -164
-33 -164
-11 -164
-10 -164
171 -164
172 -164
176 -164
183 -164
184 -164
192 -164
193 -164
194 -164
225 -164
226 -164
11 -163
15 -163
163 -163
164 -163
180 -163
181 -163
-217 -162
-216 -162
-20 -162
12 -162
13 -162
14 -162
164 -162
180 -162
181 -162
-216 -161
-22 -161
-20 -161
12 -161
13 -161
14 -161
164 -161
166 -161
174 -161
222 -161
223 -161
227 -161
228 -161
-219 -160
-218 -160
-217 -160
-21 -160
-20 -160
25 -160
60 -160
61 -160
165 -160
166 -160
174 -160
176 -160
223 -160
224 -160
225 -160
226 -160
227 -160
-219 -159
24 -159
60 -159
177 -159
178 -159
183 -159
184 -159
203 -159
223 -159
224 -159
226 -159
227 -159
-26 -158
-25 -158
24 -158
25 -158
26 -158
61 -158
62 -158
63 -158
159 -158
160 -158
177 -158
178 -158
183 -158
184 -158
202 -158
203 -158
204 -158
223 -158
224 -158
226 -158
227 -158
-111 -157
-110 -157
-27 -157
-25 -157
63 -157
159 -157
160 -157
177 -157
178 -157
201 -157
202 -157
203 -157
204 -157
205 -157
224 -157
225 -157
226 -157
-110 -156
-37 -156
-25 -156
174 -156
176 -156
200 -156
202 -156
204 -156
206 -156
-110 -155
-108 -155
-98 -155
-37 -155
-35 -155
11 -155
174 -155
200 -155
201 -155
205 -155
206 -155
-109 -154
-108 -154
-99 -154
-98 -154
-48 -154
-47 -154
-34 -154
-33 -154
-23 -154
-22 -154
10 -154
11 -154
12 -154
-207 -153
-100 -153
-99 -153
-94 -153
-93 -153
-48 -153
-47 -153
-34 -153
-33 -153
-23 -153
-22 -153
10 -153
11 -153
12 -153
27 -153
28 -153
29 -153
30 -153
31 -153
-207 -152
-206 -152
-205 -152
-101 -152
-100 -152
-99 -152
-94 -152
-93 -152
-90 -152
-89 -152
-34 -152
-33 -152
-26 -152
-25 -152
18 -152
19 -152
26 -152
28 -152
29 -152
30 -152
32 -152
-204 -151
-100 -151
-99 -151
-94 -151
-93 -151
-90 -151
-89 -151
-37 -151
-35 -151
-27 -151
-26 -151
-25 -151
8 -151
9 -151
13 -151
14 -151
18 -151
19 -151
27 -151
31 -151
159 -151
160 -151
161 -151
224 -151
225 -151
-205 -150
-204 -150
-99 -150
-98 -150
-37 -150
-26 -150
-25 -150
8 -150
9 -150
13 -150
14 -150
28 -150
29 -150
30 -150
158 -150
159 -150
161 -150
162 -150
224 -150
225 -150
-98 -149
-23 -149
-22 -149
-16 -149
-15 -149
29 -149
158 -149
159 -149
161 -149
162 -149
181 -149
182 -149
205 -149
206 -149
-23 -148
-22 -148
-16 -148
-14 -148
158 -148
159 -148
160 -148
161 -148
162 -148
180 -148
182 -148
205 -148
-14 -147
-5 -147
25 -147
31 -147
32 -147
157 -147
158 -147
162 -147
163 -147
181 -147
206 -147
207 -147
208 -147
-14 -146
-13 -146
-7 -146
-5 -146
23 -146
25 -146
31 -146
191 -146
208 -146
-23 -145
-6 -145
-5 -145
24 -145
25 -145
32 -145
33 -145
34 -145
191 -145
192 -145
-23 -144
-21 -144
13 -144
14 -144
34 -144
186 -144
187 -144
192 -144
193 -144
-205 -143
-204 -143
-200 -143
-199 -143
-40 -143
-39 -143
-20 -143
-19 -143
13 -143
161 -143
186 -143
187 -143
192 -143
193 -143
194 -143
202 -143
203 -143
-202 -142
-42 -142
-38 -142
-20 -142
-19 -142
14 -142
15 -142
16 -142
161 -142
182 -142
186 -142
187 -142
192 -142
193 -142
202 -142
203 -142
-205 -141
-199 -141
-43 -141
-37 -141
-20 -141
-19 -141
16 -141
162 -141
181 -141
182 -141
183 -141
191 -141
192 -141
-204 -140
-203 -140
-201 -140
-200 -140
-48 -140
-47 -140
-44 -140
-43 -140
-41 -140
-37 -140
-28 -140
-23 -140
-21 -140
-16 -140
-15 -140
154 -140
155 -140
180 -140
184 -140
191 -140
-203 -139
-201 -139
-48 -139
-47 -139
-43 -139
-37 -139
-27 -139
-23 -139
-16 -139
-14 -139
152 -139
155 -139
161 -139
175 -139
176 -139
179 -139
181 -139
182 -139
183 -139
185 -139
-202 -138
-42 -138
-38 -138
-32 -138
-29 -138
-28 -138
-27 -138
-14 -138
151 -138
161 -138
175 -138
176 -138
180 -138
181 -138
182 -138
183 -138
184 -138
-202 -137
-134 -137
-40 -137
-39 -137
-14 -137
-13 -137
143 -137
144 -137
151 -137
165 -137
166 -137
-135 -136
-133 -136
143 -136
144 -136
151 -136
164 -136
166 -136
175 -136
-134 -135
-132 -135
152 -135
155 -135
165 -135
174 -135
176 -135
-133 -134
-131 -134
-26 -134
-25 -134
154 -134
155 -134
174 -134
176 -134
-132 -133
-131 -133
-27 -133
-25 -133
175 -133
-203 -132
-202 -132
-25 -132
-20 -132
10 -132
40 -132
-203 -131
-202 -131
-22 -131
-20 -131
8 -131
10 -131
38 -131
40 -131
-129 -130
-128 -130
-127 -130
-21 -130
-20 -130
9 -130
10 -130
39 -130
40 -130
172 -130
173 -130
175 -130
177 -130
178 -130
-127 -129
-41 -129
-39 -129
172 -129
178 -129
-128 -128
-42 -128
-39 -128
-35 -128
-34 -128
173 -128
177 -128
-51 -127
-50 -127
-43 -127
-42 -127
-36 -127
-35 -127
-34 -127
-32 -127
-31 -127
-28 -127
-27 -127
174 -127
175 -127
176 -127
181 -127
182 -127
-124 -126
-123 -126
-51 -126
-50 -126
-45 -126
-44 -126
-40 -126
-36 -126
-32 -126
-28 -126
-26 -126
181 -126
182 -126
-124 -125
-122 -125
-43 -125
-42 -125
-36 -125
-34 -125
-25 -125
-123 -124
-121 -124
-42 -124
-39 -124
-36 -124
-35 -124
-28 -124
-25 -124
-122 -123
-120 -123
-41 -123
-39 -123
-25 -123
-121 -122
-28 -122
-26 -122
-19 -122
-18 -122
-28 -121
-27 -121
-19 -121
-17 -121
177 -121
178 -121
-17 -120
132 -120
137 -120
177 -120
-17 -119
-16 -119
130 -119
131 -119
133 -119
134 -119
135 -119
136 -119
138 -119
139 -119
178 -119
179 -119
180 -119
-27 -118
-25 -118
132 -118
137 -118
180 -118
-28 -117
-25 -117
-5 -117
25 -117
55 -117
-38 -116
-29 -116
-28 -116
-7 -116
-5 -116
23 -116
25 -116
53 -116
55 -116
-39 -115
-37 -115
-31 -115
-30 -115
-26 -115
-6 -115
-5 -115
24 -115
25 -115
54 -115
55 -115
-39 -114
-38 -114
-36 -114
-29 -114
-28 -114
-51 -113
-50 -113
-39 -113
-38 -113
-36 -113
-35 -113
-28 -113
-25 -113
-19 -113
-18 -113
-51 -112
-50 -112
-39 -112
-38 -112
-36 -112
-27 -112
-25 -112
-19 -112
-17 -112
138 -112
-39 -111
-37 -111
-17 -111
86 -111
87 -111
136 -111
138 -111
-38 -110
-17 -110
-16 -110
87 -110
134 -110
135 -110
87 -109
89 -109
96 -109
134 -109
135 -109
-86 -108
-85 -108
-27 -108
-26 -108
88 -108
89 -108
94 -108
96 -108
134 -108
135 -108
-86 -107
-85 -107
-27 -107
-26 -107
93 -107
95 -107
130 -107
131 -107
136 -107
138 -107
-89 -106
-88 -106
-77 -106
-72 -106
92 -106
95 -106
107 -106
108 -106
129 -106
131 -106
138 -106
-101 -105
-99 -105
-90 -105
-89 -105
-88 -105
-77 -105
-72 -105
-70 -105
93 -105
95 -105
107 -105
108 -105
129 -105
-101 -104
-97 -104
-89 -104
-88 -104
-77 -104
-69 -104
-68 -104
-54 -104
-53 -104
94 -104
96 -104
128 -104
129 -104
146 -104
147 -104
151 -104
152 -104
-117 -103
-97 -103
-86 -103
-85 -103
-82 -103
-81 -103
-69 -103
-68 -103
-53 -103
96 -103
146 -103
147 -103
151 -103
152 -103
-119 -102
-118 -102
-117 -102
-116 -102
-101 -102
-96 -102
-86 -102
-85 -102
-82 -102
-79 -102
-78 -102
-69 -102
-68 -102
-53 -102
-51 -102
-45 -102
-44 -102
-34 -102
-33 -102
-32 -102
-20 -102
10 -102
40 -102
70 -102
147 -102
148 -102
149 -102
150 -102
151 -102
171 -102
172 -102
-120 -101
-118 -101
-116 -101
-115 -101
-110 -101
-97 -101
-81 -101
-80 -101
-79 -101
-78 -101
-72 -101
-70 -101
-65 -101
-64 -101
-52 -101
-51 -101
-45 -101
-42 -101
-32 -101
-22 -101
-20 -101
8 -101
10 -101
38 -101
40 -101
68 -101
70 -101
148 -101
150 -101
172 -101
-125 -100
-124 -100
-121 -100
-118 -100
-116 -100
-115 -100
-114 -100
-108 -100
-107 -100
-105 -100
-101 -100
-97 -100
-80 -100
-72 -100
-65 -100
-63 -100
-41 -100
-33 -100
-27 -100
-21 -100
-20 -100
9 -100
10 -100
39 -100
40 -100
69 -100
70 -100
172 -100
174 -100
181 -100
-125 -99
-124 -99
-120 -99
-118 -99
-116 -99
-115 -99
-109 -99
-108 -99
-107 -99
-106 -99
-104 -99
-101 -99
-99 -99
-63 -99
-41 -99
-28 -99
-27 -99
-26 -99
-25 -99
148 -99
149 -99
150 -99
173 -99
174 -99
179 -99
181 -99
-119 -98
-118 -98
-117 -98
-116 -98
-109 -98
-108 -98
-105 -98
-104 -98
-63 -98
-62 -98
-41 -98
-29 -98
-28 -98
-26 -98
-24 -98
177 -98
178 -98
197 -98
198 -98
-117 -97
-80 -97
-79 -97
-69 -97
-68 -97
-45 -97
-42 -97
-30 -97
-29 -97
-28 -97
-26 -97
-23 -97
177 -97
178 -97
196 -97
200 -97
-224 -96
-223 -96
-216 -96
-215 -96
-89 -96
-87 -96
-81 -96
-78 -96
-75 -96
-74 -96
-73 -96
-70 -96
-67 -96
-45 -96
-44 -96
-29 -96
-28 -96
-26 -96
-24 -96
-23 -96
177 -96
178 -96
195 -96
201 -96
-225 -95
-222 -95
-217 -95
-214 -95
-89 -95
-88 -95
-81 -95
-80 -95
-79 -95
-76 -95
-75 -95
-74 -95
-73 -95
-72 -95
-69 -95
-68 -95
-67 -95
-28 -95
-27 -95
-26 -95
-25 -95
-23 -95
-22 -95
-21 -95
146 -95
147 -95
179 -95
181 -95
186 -95
195 -95
199 -95
201 -95
202 -95
205 -95
206 -95
-225 -94
-222 -94
-217 -94
-214 -94
-88 -94
-78 -94
-77 -94
-76 -94
-75 -94
-74 -94
-73 -94
-72 -94
-71 -94
-70 -94
-27 -94
-22 -94
-20 -94
147 -94
181 -94
185 -94
195 -94
201 -94
205 -94
206 -94
-225 -93
-222 -93
-217 -93
-214 -93
-79 -93
-69 -93
-20 -93
144 -93
145 -93
146 -93
185 -93
186 -93
187 -93
190 -93
196 -93
200 -93
-224 -92
-223 -92
-216 -92
-215 -92
-99 -92
-97 -92
-79 -92
-78 -92
-70 -92
-69 -92
-20 -92
-19 -92
144 -92
197 -92
198 -92
-98 -91
-97 -91
-98 -90
-87 -88
-86 -88
-85 -88
-84 -88
-57 -88
-56 -88
-55 -88
-54 -88
-27 -88
-26 -88
-25 -88
-24 -88
3 -88
4 -88
5 -88
6 -88
33 -88
34 -88
35 -88
36 -88
63 -88
64 -88
65 -88
66 -88
93 -88
94 -88
95 -88
96 -88
123 -88
124 -88
125 -88
126 -88
153 -88
154 -88
155 -88
156 -88
-88 -87
-84 -87
-58 -87
-54 -87
-28 -87
-24 -87
2 -87
6 -87
32 -87
36 -87
62 -87
66 -87
92 -87
96 -87
122 -87
126 -87
152 -87
156 -87
178 -87
179 -87
-113 -86
-112 -86
-84 -86
-54 -86
-24 -86
6 -86
36 -86
66 -86
96 -86
126 -86
156 -86
178 -86
179 -86
-112 -85
-88 -85
-85 -85
-58 -85
-55 -85
-28 -85
-25 -85
2 -85
5 -85
32 -85
35 -85
62 -85
65 -85
92 -85
95 -85
122 -85
125 -85
152 -85
155 -85
-112 -84
-110 -84
-105 -84
-96 -84
-93 -84
193 -84
-111 -83
-110 -83
-106 -83
-104 -83
-93 -83
190 -83
191 -83
192 -83
193 -83
-108 -82
-107 -82
-103 -82
-97 -82
-96 -82
-92 -82
-89 -82
-31 -82
-30 -82
177 -82
178 -82
189 -82
190 -82
191 -82
192 -82
202 -82
203 -82
-212 -81
-211 -81
-108 -81
-107 -81
-103 -81
-98 -81
-96 -81
-94 -81
-93 -81
-89 -81
-88 -81
-87 -81
-86 -81
-31 -81
177 -81
179 -81
189 -81
192 -81
202 -81
203 -81
-211 -80
-108 -80
-107 -80
-103 -80
-88 -80
-87 -80
-86 -80
-85 -80
-79 -80
-78 -80
-42 -80
-41 -80
-33 -80
-31 -80
168 -80
169 -80
170 -80
172 -80
173 -80
178 -80
179 -80
180 -80
189 -80
190 -80
191 -80
192 -80
198 -80
-214 -79
-213 -79
-212 -79
-155 -79
-154 -79
-106 -79
-104 -79
-98 -79
-97 -79
-88 -79
-85 -79
-79 -79
-78 -79
-42 -79
-41 -79
-40 -79
-33 -79
-32 -79
-27 -79
-26 -79
-25 -79
3 -79
4 -79
5 -79
33 -79
34 -79
35 -79
63 -79
64 -79
65 -79
168 -79
169 -79
170 -79
171 -79
174 -79
179 -79
180 -79
181 -79
190 -79
191 -79
192 -79
193 -79
198 -79
-214 -78
-157 -78
-153 -78
-105 -78
-88 -78
-87 -78
-86 -78
-85 -78
-56 -78
-40 -78
-39 -78
-37 -78
-25 -78
5 -78
35 -78
65 -78
172 -78
173 -78
178 -78
179 -78
180 -78
193 -78
-158 -77
-152 -77
-138 -77
-137 -77
-89 -77
-88 -77
-87 -77
-86 -77
-58 -77
-56 -77
-51 -77
-50 -77
-49 -77
-40 -77
-37 -77
-26 -77
4 -77
34 -77
64 -77
177 -77
179 -77
-163 -76
-162 -76
-159 -76
-158 -76
-156 -76
-152 -76
-138 -76
-137 -76
-89 -76
-59 -76
-57 -76
-40 -76
-39 -76
-37 -76
177 -76
178 -76
-163 -75
-162 -75
-158 -75
-152 -75
-141 -75
-140 -75
-65 -75
-64 -75
-60 -75
-57 -75
-49 -75
-46 -75
-45 -75
-42 -75
-41 -75
-40 -75
-157 -74
-153 -74
-142 -74
-141 -74
-140 -74
-65 -74
-64 -74
-59 -74
-57 -74
-49 -74
-45 -74
-42 -74
-41 -74
-155 -73
-154 -73
-141 -73
-140 -73
-58 -73
-56 -73
-49 -73
-46 -73
-150 -72
-148 -72
-138 -72
-137 -72
-131 -72
-130 -72
-56 -72
-47 -72
-46 -72
-150 -71
-149 -71
-138 -71
-137 -71
-131 -71
-129 -71
-149 -70
-129 -70
-129 -69
-128 -69
-53 -64
-52 -64
-42 -64
-41 -64
-40 -64
-28 -64
-27 -64
-12 -64
-11 -64
-10 -64
18 -64
19 -64
20 -64
48 -64
49 -64
50 -64
-144 -63
-143 -63
-133 -63
-61 -63
-53 -63
-50 -63
-40 -63
-28 -63
-10 -63
20 -63
50 -63
-145 -62
-144 -62
-143 -62
-142 -62
-134 -62
-132 -62
-62 -62
-58 -62
-57 -62
-49 -62
-41 -62
-35 -62
-30 -62
-28 -62
-11 -62
19 -62
49 -62
-150 -61
-148 -61
-145 -61
-142 -61
-141 -61
-140 -61
-134 -61
-133 -61
-131 -61
-62 -61
-56 -61
-49 -61
-36 -61
-35 -61
-34 -61
-33 -61
-31 -61
-30 -61
-29 -61
-151 -60
-148 -60
-145 -60
-144 -60
-134 -60
-133 -60
-131 -60
-130 -60
-126 -60
-125 -60
-61 -60
-60 -60
-59 -60
-58 -60
-57 -60
-49 -60
-37 -60
-36 -60
-34 -60
-32 -60
-31 -60
-152 -59
-151 -59
-141 -59
-134 -59
-133 -59
-131 -59
-126 -59
-125 -59
-53 -59
-50 -59
-38 -59
-37 -59
-36 -59
-34 -59
-31 -59
-154 -58
-153 -58
-149 -58
-140 -58
-134 -58
-132 -58
-53 -58
-52 -58
-37 -58
-36 -58
-34 -58
-32 -58
-182 -57
-165 -57
-163 -57
-152 -57
-151 -57
-140 -57
-133 -57
-36 -57
-35 -57
-34 -57
-33 -57
-187 -56
-186 -56
-185 -56
-183 -56
-182 -56
-179 -56
-178 -56
-165 -56
-164 -56
-158 -56
-157 -56
-151 -56
-148 -56
-35 -56
-187 -55
-186 -55
-185 -55
-184 -55
-179 -55
-178 -55
-164 -55
-159 -55
-157 -55
-150 -55
-148 -55
-28 -55
-27 -55
-183 -54
-182 -54
-159 -54
-28 -54
-160 -53
-159 -53
-39 -53
-37 -53
-30 -53
-28 -53
-41 -52
-37 -52
-30 -52
-29 -52
-49 -51
-41 -51
-50 -50
-49 -50
-48 -50
-47 -50
-42 -50
-37 -50
-51 -49
-50 -49
-48 -49
-46 -49
-41 -49
-27 -49
-26 -49
-25 -49
3 -49
4 -49
5 -49
33 -49
34 -49
35 -49
-89 -48
-62 -48
-61 -48
-52 -48
-51 -48
-50 -48
-48 -48
-45 -48
-41 -48
-37 -48
-25 -48
5 -48
35 -48
-91 -47
-90 -47
-89 -47
-62 -47
-61 -47
-51 -47
-50 -47
-48 -47
-46 -47
-39 -47
-37 -47
-26 -47
4 -47
34 -47
-92 -46
-50 -46
-49 -46
-48 -46
-47 -46
-92 -45
-91 -45
-49 -45
-226 -44
-38 -44
-230 -43
-229 -43
-226 -43
-225 -43
-223 -43
-222 -43
-221 -43
-186 -43
-185 -43
-40 -43
-38 -43
-230 -42
-229 -42
-224 -42
-223 -42
-222 -42
-221 -42
-194 -42
-186 -42
-184 -42
-180 -42
-178 -42
-39 -42
-38 -42
-226 -41
-225 -41
-194 -41
-193 -41
-192 -41
-186 -41
-180 -41
-179 -41
-236 -40
-235 -40
-219 -40
-218 -40
-217 -40
-191 -40
-179 -40
-35 -40
-34 -40
-236 -39
-235 -39
-217 -39
-192 -39
-191 -39
-59 -39
-58 -39
-35 -39
-34 -39
-218 -38
-58 -38
-213 -37
-58 -37
-56 -37
-49 -37
-47 -37
-25 -37
-24 -37
24 -37
25 -37
-215 -36
-214 -36
-213 -36
-57 -36
-56 -36
-50 -36
-47 -36
-43 -36
-42 -36
-25 -36
24 -36
25 -36
26 -36
-216 -35
-165 -35
-96 -35
-95 -35
-94 -35
-93 -35
-92 -35
-60 -35
-51 -35
-50 -35
-44 -35
-43 -35
-42 -35
-40 -35
-39 -35
-36 -35
-35 -35
-27 -35
-25 -35
-216 -34
-215 -34
-165 -34
-164 -34
-163 -34
-97 -34
-95 -34
-94 -34
-93 -34
-91 -34
-62 -34
-61 -34
-60 -34
-53 -34
-52 -34
-48 -34
-44 -34
-40 -34
-36 -34
-34 -34
-27 -34
-26 -34
-12 -34
-11 -34
-10 -34
18 -34
19 -34
20 -34
26 -34
27 -34
28 -34
-237 -33
-236 -33
-235 -33
-162 -33
-96 -33
-92 -33
-63 -33
-51 -33
-50 -33
-44 -33
-42 -33
-33 -33
-10 -33
20 -33
26 -33
28 -33
29 -33
-238 -32
-237 -32
-235 -32
-234 -32
-183 -32
-163 -32
-162 -32
-95 -32
-94 -32
-93 -32
-63 -32
-62 -32
-50 -32
-47 -32
-44 -32
-43 -32
-36 -32
-33 -32
-11 -32
19 -32
26 -32
27 -32
28 -32
29 -32
-238 -31
-237 -31
-235 -31
-234 -31
-183 -31
-182 -31
-181 -31
-94 -31
-49 -31
-47 -31
-33 -31
-7 -31
-6 -31
-238 -30
-237 -30
-236 -30
-235 -30
-234 -30
-229 -30
-228 -30
-180 -30
-36 -30
-34 -30
-6 -30
-239 -29
-238 -29
-234 -29
-233 -29
-210 -29
-207 -29
-205 -29
-204 -29
-202 -29
-199 -29
-181 -29
-180 -29
-36 -29
-35 -29
-6 -29
-4 -29
2 -29
4 -29
-229 -28
-226 -28
-210 -28
-209 -28
-208 -28
-207 -28
-205 -28
-204 -28
-202 -28
-201 -28
-200 -28
-199 -28
-171 -28
-170 -28
-161 -28
-160 -28
-159 -28
-131 -28
-130 -28
-25 -28
-24 -28
-5 -28
-4 -28
0 -28
4 -28
10 -28
11 -28
12 -28
-225 -27
-219 -27
-218 -27
-217 -27
-210 -27
-207 -27
-205 -27
-204 -27
-202 -27
-199 -27
-171 -27
-169 -27
-162 -27
-161 -27
-159 -27
-158 -27
-131 -27
-95 -27
-94 -27
-25 -27
0 -27
8 -27
10 -27
13 -27
16 -27
17 -27
-233 -26
-227 -26
-220 -26
-216 -26
-171 -26
-162 -26
-161 -26
-159 -26
-158 -26
-133 -26
-131 -26
-95 -26
-94 -26
-66 -26
-65 -26
-64 -26
-59 -26
-58 -26
-32 -26
-27 -26
-25 -26
-1 -26
4 -26
12 -26
13 -26
16 -26
19 -26
35 -26
36 -26
46 -26
47 -26
231 -26
232 -26
-234 -25
-232 -25
-231 -25
-221 -25
-215 -25
-162 -25
-161 -25
-160 -25
-159 -25
-158 -25
-133 -25
-132 -25
-108 -25
-67 -25
-63 -25
-58 -25
-33 -25
-31 -25
-27 -25
-26 -25
0 -25
20 -25
34 -25
35 -25
45 -25
47 -25
231 -25
-234 -24
-221 -24
-215 -24
-163 -24
-162 -24
-158 -24
-157 -24
-110 -24
-109 -24
-108 -24
-58 -24
-56 -24
-50 -24
-49 -24
-33 -24
-32 -24
-30 -24
0 -24
4 -24
7 -24
8 -24
9 -24
20 -24
29 -24
36 -24
44 -24
45 -24
46 -24
221 -24
222 -24
229 -24
231 -24
-170 -23
-169 -23
-111 -23
-68 -23
-62 -23
-57 -23
-56 -23
-50 -23
-48 -23
-33 -23
-32 -23
-30 -23
-29 -23
2 -23
4 -23
20 -23
28 -23
30 -23
43 -23
44 -23
45 -23
220 -23
222 -23
228 -23
229 -23
230 -23
-234 -22
-233 -22
-231 -22
-221 -22
-179 -22
-178 -22
-177 -22
-171 -22
-169 -22
-111 -22
-110 -22
-68 -22
-67 -22
-63 -22
-62 -22
-47 -22
-33 -22
-32 -22
-30 -22
16 -22
19 -22
26 -22
27 -22
31 -22
44 -22
45 -22
46 -22
210 -22
211 -22
219 -22
226 -22
227 -22
228 -22
-236 -21
-233 -21
-221 -21
-220 -21
-180 -21
-176 -21
-169 -21
-163 -21
-50 -21
-47 -21
-33 -21
-31 -21
16 -21
17 -21
26 -21
27 -21
31 -21
45 -21
47 -21
53 -21
54 -21
210 -21
211 -21
219 -21
222 -21
225 -21
228 -21
-236 -20
-234 -20
-221 -20
-220 -20
-181 -20
-175 -20
-165 -20
-164 -20
-162 -20
-47 -20
-38 -20
-32 -20
26 -20
27 -20
31 -20
46 -20
47 -20
53 -20
55 -20
219 -20
226 -20
227 -20
-222 -19
-221 -19
-218 -19
-181 -19
-175 -19
-162 -19
-141 -19
-140 -19
-65 -19
-50 -19
-48 -19
-40 -19
-38 -19
-27 -19
-26 -19
-25 -19
28 -19
30 -19
55 -19
220 -19
222 -19
-221 -18
-219 -18
-142 -18
-140 -18
-66 -18
-64 -18
-50 -18
-49 -18
-39 -18
-38 -18
-25 -18
29 -18
55 -18
56 -18
221 -18
222 -18
-220 -17
-219 -17
-175 -17
-165 -17
-163 -17
-162 -17
-140 -17
-113 -17
-66 -17
-64 -17
-26 -17
-176 -16
-175 -16
-163 -16
-160 -16
-114 -16
-113 -16
-112 -16
-64 -16
-235 -15
-234 -15
-233 -15
-176 -15
-175 -15
-162 -15
-160 -15
-115 -15
-114 -15
-113 -15
-112 -15
-111 -15
-64 -15
-236 -14
-232 -14
-223 -14
-222 -14
-218 -14
-217 -14
-178 -14
-175 -14
-174 -14
-116 -14
-114 -14
-112 -14
-110 -14
-67 -14
-64 -14
-237 -13
-231 -13
-223 -13
-222 -13
-218 -13
-217 -13
-177 -13
-175 -13
-116 -13
-115 -13
-111 -13
-110 -13
-66 -13
-65 -13
-32 -13
-31 -13
86 -13
-236 -12
-232 -12
-177 -12
-176 -12
-137 -12
-136 -12
-32 -12
-31 -12
86 -12
87 -12
88 -12
-235 -11
-234 -11
-233 -11
-221 -11
-220 -11
-219 -11
-149 -11
-148 -11
-147 -11
-138 -11
-137 -11
-136 -11
-95 -11
-94 -11
89 -11
-235 -10
-234 -10
-233 -10
-221 -10
-220 -10
-219 -10
-163 -10
-162 -10
-161 -10
-147 -10
-141 -10
-139 -10
-138 -10
-113 -10
-95 -10
-45 -10
-22 -10
-21 -10
88 -10
89 -10
-220 -9
-179 -9
-178 -9
-174 -9
-173 -9
-164 -9
-160 -9
-148 -9
-141 -9
-138 -9
-133 -9
-132 -9
-131 -9
-114 -9
-112 -9
-111 -9
-106 -9
-105 -9
-97 -9
-95 -9
-45 -9
-43 -9
-22 -9
-179 -8
-178 -8
-174 -8
-173 -8
-165 -8
-159 -8
-141 -8
-139 -8
-138 -8
-132 -8
-130 -8
-129 -8
-114 -8
-106 -8
-104 -8
-97 -8
-96 -8
-56 -8
-55 -8
-42 -8
-41 -8
-31 -8
-30 -8
-24 -8
-22 -8
-164 -7
-160 -7
-146 -7
-145 -7
-138 -7
-137 -7
-136 -7
-132 -7
-130 -7
-129 -7
-113 -7
-110 -7
-103 -7
-56 -7
-55 -7
-42 -7
-41 -7
-31 -7
-30 -7
-24 -7
-23 -7
-234 -6
-233 -6
-177 -6
-176 -6
-175 -6
-163 -6
-162 -6
-161 -6
-147 -6
-145 -6
-137 -6
-136 -6
-131 -6
-129 -6
-109 -6
-106 -6
-103 -6
-42 -6
-41 -6
-34 -6
-33 -6
-234 -5
-233 -5
-177 -5
-176 -5
-175 -5
-163 -5
-162 -5
-161 -5
-147 -5
-111 -5
-110 -5
-103 -5
-45 -5
-43 -5
-35 -5
-34 -5
-33 -5
-176 -4
-156 -4
-155 -4
-148 -4
-147 -4
-106 -4
-104 -4
-87 -4
-45 -4
-34 -4
-33 -4
88 -4
89 -4
93 -4
94 -4
-221 -3
-220 -3
-165 -3
-164 -3
-157 -3
-155 -3
-106 -3
-105 -3
-89 -3
-88 -3
-87 -3
-31 -3
-30 -3
91 -3
-221 -2
-220 -2
-164 -2
-155 -2
-132 -2
-131 -2
-127 -2
-126 -2
-90 -2
-31 -2
-30 -2
88 -2
94 -2
-167 -1
-166 -1
-165 -1
-129 -1
-90 -1
-89 -1
-58 -1
-57 -1
89 -1
90 -1
92 -1
93 -1
-179 0
-178 0
-167 0
-132 0
-126 0
-58 0
90 0
92 0
-178 1
-131 1
-130 1
-128 1
-127 1
-93 1
-92 1
-91 1
-69 1
-67 1
-60 1
-58 1
91 1
101 1
103 1
-181 2
-180 2
-179 2
-130 2
-128 2
-93 2
-92 2
-91 2
-69 2
-65 2
-60 2
-59 2
91 2
100 2
103 2
-181 3
-129 3
-94 3
-90 3
-65 3
99 3
100 3
-164 4
-163 4
-162 4
-129 4
-95 4
-89 4
-79 4
-78 4
-69 4
-64 4
97 4
98 4
102 4
185 4
-162 5
-94 5
-90 5
-79 5
-78 5
-65 5
99 5
100 5
183 5
184 5
185 5
-173 6
-163 6
-152 6
-151 6
-93 6
-92 6
-91 6
-69 6
-65 6
100 6
103 6
109 6
110 6
182 6
-174 7
-172 7
-152 7
-132 7
-131 7
-69 7
-67 7
101 7
103 7
109 7
111 7
182 7
183 7
-186 8
-185 8
-174 8
-173 8
-171 8
-162 8
-160 8
-154 8
-152 8
-131 8
111 8
159 8
-186 9
-185 9
-174 9
-173 9
-171 9
-170 9
-163 9
-160 9
-154 9
-153 9
-134 9
-133 9
-132 9
-118 9
-47 9
-46 9
-26 9
-25 9
111 9
112 9
157 9
158 9
159 9
-174 10
-173 10
-171 10
-164 10
-163 10
-134 10
-120 10
-118 10
-74 10
-73 10
-46 10
-26 10
103 10
156 10
-174 11
-172 11
-166 11
-165 11
-161 11
-121 11
-119 11
-74 11
-46 11
-44 11
-36 11
-35 11
-28 11
-26 11
101 11
102 11
103 11
156 11
157 11
180 11
-173 12
-164 12
-163 12
-122 12
-119 12
-108 12
-81 12
-76 12
-74 12
-45 12
-44 12
-38 12
-35 12
-28 12
-27 12
100 12
178 12
179 12
181 12
182 12
218 12
219 12
239 12
240 12
-163 13
-160 13
-121 13
-119 13
-107 13
-82 13
-80 13
-76 13
-75 13
-39 13
100 13
101 13
219 13
239 13
-162 14
-160 14
-125 14
-124 14
-120 14
-118 14
-107 14
-93 14
-92 14
-82 14
-81 14
-79 14
-39 14
-32 14
177 14
183 14
219 14
221 14
228 14
237 14
239 14
-126 15
-124 15
-118 15
-82 15
-81 15
-79 15
-78 15
-39 15
-31 15
-30 15
98 15
220 15
221 15
228 15
229 15
230 15
231 15
237 15
238 15
-126 16
-82 16
-81 16
-79 16
-38 16
-35 16
97 16
99 16
177 16
178 16
180 16
182 16
183 16
229 16
230 16
231 16
232 16
-127 17
-126 17
-82 17
-80 17
-66 17
-36 17
-35 17
96 17
100 17
229 17
232 17
-81 18
-68 18
-67 18
-66 18
96 18
97 18
98 18
99 18
100 18
229 18
230 18
231 18
232 18
-69 19
95 19
96 19
100 19
101 19
151 19
152 19
156 19
157 19
228 19
229 19
230 19
231 19
-68 20
96 20
97 20
98 20
99 20
100 20
152 20
153 20
154 20
155 20
156 20
228 20
-71 21
-68 21
97 21
98 21
99 21
152 21
153 21
155 21
156 21
-110 22
-109 22
-108 22
-107 22
-106 22
-72 22
98 22
152 22
153 22
155 22
156 22
-111 23
-109 23
-108 23
-107 23
-105 23
-73 23
-69 23
153 23
154 23
155 23
177 23
178 23
-110 24
-106 24
-71 24
178 24
-109 25
-108 25
-107 25
-74 25
-68 25
175 25
176 25
177 25
-108 26
-74 26
-68 26
175 26
-73 27
-69 27
151 27
152 27
-111 28
-110 28
-72 28
-71 28
-70 28
152 28
-110 29
95 29
96 29
149 29
150 29
151 29
-113 30
-112 30
-111 30
-97 30
-96 30
96 30
149 30
-113 31
-97 31
-95 31
-53 31
-52 31
93 31
94 31
95 31
-96 32
-95 32
-94 32
-53 32
93 32
-95 33
-94 33
-93 33
-60 33
-55 33
-53 33
-96 34
-95 34
-94 34
-61 34
-60 34
-59 34
-58 34
-56 34
-55 34
-54 34
-3 34
-2 34
19 34
20 34
-104 35
-103 35
-97 35
-95 35
-62 35
-61 35
-59 35
-57 35
-56 35
-2 35
19 35
-105 36
-103 36
-97 36
-96 36
-63 36
-62 36
-61 36
-59 36
-56 36
-2 36
0 36
7 36
8 36
17 36
19 36
-105 37
-62 37
-61 37
-59 37
-57 37
-1 37
0 37
7 37
10 37
17 37
18 37
-106 38
-105 38
-61 38
-60 38
-59 38
-58 38
-45 38
11 38
-88 39
-87 39
-86 39
-60 39
-47 39
-46 39
-45 39
4 39
11 39
-89 40
-85 40
-48 40
2 40
3 40
11 40
-48 41
-47 41
7 41
10 41
-90 42
-84 42
7 42
8 42
-90 43
-89 43
-85 43
-84 43
-53 48
-52 48
-48 48
-47 48
-90 49
-89 49
-52 49
-51 49
-50 49
-49 49
-48 49
-89 50
-52 50
-51 50
-49 50
-48 50
-92 51
-91 51
-90 51
-77 51
-52 51
-51 51
-49 51
-48 51
-141 52
-131 52
-130 52
-92 52
-79 52
-78 52
-77 52
-76 52
-51 52
-50 52
-49 52
-32 52
-31 52
-142 53
-140 53
-132 53
-131 53
-130 53
-129 53
-80 53
-78 53
-76 53
-75 53
-32 53
-143 54
-141 54
-140 54
-133 54
-131 54
-129 54
-126 54
-124 54
-81 54
-78 54
-76 54
-75 54
-74 54
-42 54
-40 54
-34 54
-32 54
-149 55
-148 55
-144 55
-143 55
-141 55
-140 55
-132 55
-131 55
-129 55
-128 55
-126 55
-123 55
-81 55
-80 55
-78 55
-76 55
-75 55
-43 55
-40 55
-34 55
-33 55
-149 56
-148 56
-143 56
-141 56
-140 56
-132 56
-131 56
-129 56
-123 56
-122 56
-83 56
-82 56
-81 56
-79 56
-78 56
-77 56
-76 56
-44 56
-43 56
-142 57
-140 57
-131 57
-130 57
-125 57
-121 57
-120 57
-84 57
-82 57
-77 57
-46 57
-45 57
-41 57
-141 58
-133 58
-132 58
-131 58
-123 58
-122 58
-84 58
-44 58
-43 58
-131 59
-126 59
-123 59
-117 59
-116 59
-85 59
-84 59
-43 59
-40 59
-133 60
-126 60
-124 60
-117 60
-115 60
-42 60
-40 60
-132 61
-131 61
-115 61
-115 62
-114 62
-67 62
-66 62
-65 62
-68 63
-64 63
-69 64
-63 64
-69 65
-63 65
-149 66
-148 66
-138 66
-137 66
-66 66
-36 66
-35 66
-149 67
-147 67
-137 67
-136 67
-68 67
-64 67
-38 67
-35 67
-158 68
-157 68
-156 68
-154 68
-153 68
-148 68
-147 68
-146 68
-138 68
-131 68
-65 68
-53 68
-45 68
-39 68
-31 68
-30 68
-29 68
-28 68
-27 68
-158 69
-157 69
-156 69
-155 69
-152 69
-147 69
-146 69
-145 69
-132 69
-130 69
-69 69
-66 69
-55 69
-54 69
-53 69
-52 69
-46 69
-45 69
-39 69
-32 69
-26 69
-154 70
-153 70
-148 70
-147 70
-146 70
-133 70
-129 70
-128 70
-69 70
-56 70
-54 70
-52 70
-51 70
-46 70
-45 70
-39 70
-31 70
-30 70
-26 70
-149 71
-147 71
-133 71
-129 71
-128 71
-87 71
-68 71
-57 71
-54 71
-52 71
-51 71
-50 71
-38 71
-35 71
-27 71
-149 72
-148 72
-133 72
-129 72
-128 72
-87 72
-86 72
-85 72
-71 72
-70 72
-69 72
-57 72
-56 72
-54 72
-52 72
-51 72
-36 72
-35 72
-132 73
-130 73
-126 73
-125 73
-84 73
-71 73
-59 73
-58 73
-57 73
-55 73
-54 73
-53 73
-52 73
-215 74
-131 74
-126 74
-124 74
-85 74
-84 74
-60 74
-58 74
-53 74
-215 75
-214 75
-213 75
-124 75
-60 75
-34 75
-212 76
-124 76
-123 76
-81 76
-61 76
-60 76
-34 76
-33 76
-32 76
-213 77
-212 77
-81 77
-31 77
-58 78
-40 78
-39 78
-32 78
-31 78
-211 79
-210 79
-209 79
-58 79
-57 79
-56 79
-40 79
-38 79
-211 80
-210 80
-209 80
-85 80
-84 80
-80 80
-79 80
-55 80
-40 80
-212 81
-208 81
-84 81
-83 81
-82 81
-81 81
-80 81
-56 81
-55 81
-213 82
-207 82
-83 82
-82 82
-81 82
-229 83
-212 83
-208 83
-82 83
-229 84
-228 84
-227 84
-211 84
-210 84
-209 84
-226 85
-54 85
-53 85
-52 85
-227 86
-226 86
-55 86
-54 86
-52 86
-51 86
-33 86
-32 86
-31 86
-55 87
-54 87
-52 87
-51 87
-33 87
-13 87
-12 87
-55 88
-54 88
-53 88
-52 88
-51 88
-32 88
-13 88
-12 88
-209 89
-208 89
-206 89
-56 89
-55 89
-51 89
-50 89
-208 90
-207 90
-85 90
-84 90
-84 91
-227 92
-226 92
-222 92
-221 92
-87 92
-86 92
-85 92
-38 92
-37 92
-13 92
-227 93
-221 93
-87 93
-38 93
-37 93
-25 93
-24 93
-14 93
-13 93
-12 93
-25 94
-23 94
-15 94
-11 94
-226 95
-222 95
-219 95
-218 95
-25 95
-16 95
-14 95
-13 95
-12 95
-10 95
-225 96
-224 96
-223 96
-218 96
-217 96
-208 96
-15 96
-14 96
-13 96
-12 96
-11 96
-219 97
-209 97
-208 97
-207 97
-51 97
-50 97
-210 98
-209 98
-208 98
-207 98
-206 98
-51 98
-211 99
-209 99
-207 99
-205 99
-50 99
-49 99
-48 99
25 99
27 99
-211 100
-210 100
-206 100
-205 100
-48 100
23 100
27 100
-18 101
-17 101
-16 101
23 101
-18 102
16 102
17 102
22 102
27 102
-222 103
-208 103
-17 103
16 103
17 103
23 103
-224 104
-223 104
-221 104
-220 104
-209 104
-207 104
23 104
27 104
35 104
36 104
-209 105
-207 105
25 105
27 105
35 105
37 105
-225 106
-219 106
-208 106
37 106
-209 107
-208 107
37 107
38 107
-225 108
-224 108
-222 108
-220 108
-219 108
-209 108
-208 108
23 108
24 108
-209 109
-208 109
23 109
-16 110
-15 110
-14 110
15 110
21 110
23 110
-17 111
-13 111
14 111
16 111
21 111
22 111
-18 112
-12 112
13 112
17 112
18 112
-18 113
-17 113
-15 113
-13 113
-12 113
13 113
17 113
18 113
13 114
17 114
18 114
4 115
5 115
14 115
16 115
3 116
5 116
15 116
-222 117
-221 117
-199 117
-198 117
3 117
-222 118
-221 118
-198 118
2 118
3 118
-198 119
-196 119
-187 119
-186 119
-18 119
-17 119
-197 120
-196 120
-188 120
-186 120
-17 120
-189 121
-182 121
-181 121
-20 121
-19 121
-18 121
-189 122
-186 122
-183 122
-180 122
-178 122
-177 122
-20 122
-189 123
-182 123
-181 123
-178 123
-177 123
-188 124
-186 124
-187 125
-186 125
74 125
69 126
74 126
75 126
76 126
77 126
69 127
75 127
76 127
77 127
78 127
27 128
64 128
65 128
75 128
78 128
22 129
27 129
28 129
29 129
30 129
64 129
65 129
75 129
76 129
77 129
78 129
22 130
28 130
29 130
30 130
31 130
74 130
75 130
76 130
77 130
83 130
84 130
17 131
18 131
28 131
31 131
74 131
83 131
85 131
17 132
18 132
28 132
29 132
30 132
31 132
85 132
135 132
136 132
27 133
28 133
29 133
30 133
36 133
37 133
85 133
86 133
135 133
136 133
27 134
36 134
38 134
38 135
38 136
39 136
138 136
137 137
137 138
-170 141
-169 141
133 141
134 141
138 141
139 141
-170 142
-169 142
-168 142
136 142
-168 143
-167 143
-165 143
-159 143
-158 143
133 143
139 143
-168 144
-165 144
-159 144
-158 144
134 144
135 144
137 144
138 144
-168 145
-167 145
-165 145
135 145
137 145
-178 146
-177 146
-170 146
-169 146
-168 146
136 146
145 146
-179 147
-177 147
-170 147
-169 147
136 147
143 147
145 147
-179 148
142 148
144 148
156 148
157 148
-180 149
-179 149
141 149
144 149
156 149
157 149
-142 150
142 150
144 150
-142 151
-141 151
-140 151
143 151
145 151
-139 152
145 152
162 152
-140 153
-139 153
135 153
160 153
161 153
162 153
134 154
136 154
159 154
-137 155
135 155
136 155
159 155
160 155
-138 156
-136 156
-139 157
-135 157
156 157
157 157
158 157
-138 158
-137 158
-136 158
156 158
157 158
158 158
-140 159
-139 159
-135 159
-134 159
155 159
159 159
154 160
160 160
163 160
164 160
-170 161
-169 161
126 161
127 161
155 161
159 161
163 161
164 161
-170 162
-169 162
126 162
127 162
156 162
157 162
158 162
129 163
130 163
-183 164
-182 164
-150 164
-149 164
129 164
130 164
131 164
137 164
138 164
-183 165
-182 165
-167 165
-152 165
-148 165
129 165
130 165
137 165
138 165
-168 166
-158 166
-157 166
-153 166
-147 166
119 166
120 166
126 166
127 166
-168 167
-158 167
-157 167
-154 167
-153 167
-151 167
-147 167
118 167
120 167
126 167
127 167
163 167
164 167
165 167
-153 168
-147 168
118 168
133 168
134 168
162 168
163 168
165 168
166 168
-152 169
-148 169
117 169
118 169
131 169
135 169
147 169
162 169
163 169
165 169
166 169
-172 170
-171 170
-167 170
-166 170
-163 170
-150 170
-149 170
125 170
126 170
130 170
136 170
146 170
148 170
162 170
163 170
164 170
165 170
166 170
-169 171
-163 171
-162 171
-161 171
125 171
126 171
129 171
130 171
132 171
136 171
147 171
148 171
161 171
162 171
166 171
167 171
-172 172
-166 172
-160 172
-136 172
-135 172
130 172
136 172
157 172
158 172
-171 173
-170 173
-168 173
-167 173
-161 173
-160 173
-136 173
-135 173
131 173
135 173
157 173
158 173
-184 174
-183 174
-182 174
-170 174
-168 174
133 174
134 174
177 174
-185 175
-181 175
-169 175
176 175
178 175
-186 176
-180 176
-169 176
176 176
177 176
179 176
184 176
185 176
-186 177
-180 177
176 177
177 177
179 177
180 177
184 177
185 177
-183 178
176 178
177 178
179 178
-185 179
-181 179
-159 179
-158 179
-157 179
-129 179
-127 179
141 179
142 179
143 179
176 179
178 179
-184 180
-183 180
-182 180
-160 180
-156 180
-129 180
-125 180
140 180
144 180
177 180
-183 181
-161 181
-155 181
-125 181
163 181
-173 182
-171 182
-161 182
-160 182
-158 182
-156 182
-155 182
-139 182
-138 182
-129 182
-124 182
139 182
145 182
162 182
164 182
-173 183
-172 183
-139 183
-138 183
-125 183
139 183
140 183
144 183
145 183
163 183
164 183
-186 184
-185 184
-184 184
-172 184
-168 184
-167 184
-166 184
-129 184
-125 184
-121 184
-120 184
-186 185
-185 185
-184 185
-169 185
-165 185
-158 185
-129 185
-127 185
-121 185
-119 185
-187 186
-183 186
-170 186
-164 186
-159 186
-157 186
-138 186
-137 186
-119 186
142 186
169 186
170 186
-179 187
-177 187
-170 187
-169 187
-167 187
-165 187
-164 187
-159 187
-157 187
-147 187
-146 187
-138 187
-135 187
-119 187
-118 187
141 187
143 187
169 187
171 187
-188 188
-187 188
-183 188
-182 188
-178 188
-177 188
-158 188
-148 188
-147 188
-146 188
-134 188
-127 188
-126 188
141 188
143 188
169 188
-178 189
-147 189
-145 189
-144 189
-134 189
-127 189
-126 189
143 189
156 189
157 189
163 189
-159 190
-158 190
-134 190
143 190
155 190
156 190
157 190
161 190
165 190
-159 191
-158 191
-144 191
-138 191
-135 191
140 191
143 191
152 191
154 191
155 191
161 191
-138 192
-137 192
46 192
141 192
142 192
152 192
155 192
160 192
166 192
-165 193
-164 193
-145 193
44 193
45 193
46 193
152 193
154 193
155 193
165 193
166 193
-165 194
-144 194
43 194
147 194
148 194
155 194
156 194
157 194
169 194
-164 195
-163 195
-162 195
-144 195
43 195
44 195
146 195
148 195
156 195
157 195
169 195
170 195
171 195
-183 196
-182 196
-162 196
146 196
172 196
-183 197
145 197
146 197
171 197
172 197
-182 198
-181 198
-180 198
-180 199
-146 199
-145 199
-141 199
-140 199
40 199
41 199
42 199
-145 200
-144 200
-143 200
-142 200
-141 200
39 200
40 200
42 200
43 200
-145 201
-144 201
-142 201
-141 201
39 201
40 201
42 201
43 201
60 201
-176 202
-173 202
-172 202
-156 202
-154 202
-145 202
-144 202
-142 202
-141 202
39 202
40 202
41 202
42 202
43 202
58 202
59 202
60 202
-177 203
-173 203
-172 203
-169 203
-168 203
-156 203
-153 203
-144 203
-143 203
-142 203
38 203
39 203
43 203
44 203
57 203
172 203
173 203
-177 204
-169 204
-168 204
-153 204
-152 204
57 204
58 204
168 204
169 204
172 204
173 204
-176 205
-175 205
-174 205
-173 205
-155 205
-151 205
-150 205
38 205
39 205
55 205
56 205
57 205
168 205
169 205
-153 206
-152 206
39 206
40 206
54 206
56 206
-164 207
-163 207
-156 207
-153 207
-147 207
-146 207
-141 207
-140 207
36 207
37 207
39 207
40 207
53 207
57 207
-165 208
-163 208
-156 208
-154 208
-147 208
-145 208
-141 208
53 208
54 208
55 208
56 208
57 208
203 208
204 208
-165 209
-145 209
-140 209
-139 209
-138 209
43 209
44 209
52 209
53 209
57 209
58 209
171 209
172 209
191 209
192 209
193 209
196 209
202 209
206 209
-166 210
-165 210
-145 210
-144 210
-138 210
36 210
45 210
53 210
54 210
55 210
56 210
57 210
172 210
173 210
187 210
191 210
201 210
207 210
211 210
212 210
38 211
39 211
41 211
43 211
54 211
55 211
56 211
161 211
171 211
185 211
187 211
192 211
201 211
205 211
207 211
208 211
211 211
212 211
55 212
161 212
163 212
183 212
184 212
201 212
207 212
149 213
150 213
162 213
164 213
174 213
175 213
183 213
184 213
202 213
206 213
50 214
51 214
149 214
150 214
162 214
165 214
173 214
174 214
175 214
183 214
184 214
203 214
204 214
50 215
52 215
162 215
164 215
170 215
172 215
173 215
179 215
180 215
185 215
187 215
50 216
161 216
163 216
170 216
173 216
178 216
181 216
187 216
38 217
39 217
40 217
161 217
170 217
172 217
173 217
179 217
180 217
-41 218
37 218
41 218
173 218
174 218
175 218
-46 219
-41 219
-40 219
-39 219
-38 219
36 219
42 219
174 219
175 219
-46 220
-40 220
-39 220
-38 220
-37 220
37 220
41 220
-51 221
-50 221
-40 221
-37 221
38 221
39 221
40 221
-51 222
-50 222
-40 222
-39 222
-38 222
-37 222
38 222
39 222
40 222
-41 223
-40 223
-39 223
-38 223
-32 223
-31 223
52 223
53 223
54 223
-41 224
-32 224
-30 224
41 224
42 224
51 224
55 224
-30 225
41 225
-30 226
-29 226
42 226
43 226
44 226
50 226
56 226
44 227
50 227
51 227
55 227
56 227
53 230
52 231
54 231
52 232
54 232
54 233
54 234
51 235
54 235
52 236
53 236
-247 246
247 246
-248 247
-246 247
246 247
248 247
-249 248
-247 248
247 248
249 248
-249 249
-248 249
248 249
249 249
